@@ -4,12 +4,12 @@ use JSON;
 
 # ABSTRACT: Parse progress data from a file
 
-our $VERSION= '0.00_02';
+our $VERSION= '0.02';
 
 
 has input     => ( is => 'rw' );
 has input_pos => ( is => 'rw' );
-has status    => ( is => 'rw', default => sub { {} } );
+has state     => ( is => 'rw', default => sub { {} } );
 has on_data   => ( is => 'rw' );
 
 
@@ -19,7 +19,7 @@ sub parse {
 	if (!ref $fh) {
 		my $input= $fh;
 		undef $fh;
-		open $fh, '<', \$input or die;
+		open $fh, '<', \$input or die "open(scalar): $!";
 	}
 	if ($self->input_pos) {
 		seek($fh, $self->input_pos, 0)
@@ -29,39 +29,40 @@ sub parse {
 	#  Substeps will make that rather complicated.
 	my $pos;
 	my %parent_cleanup;
+	local $_;
 	while (<$fh>) {
 		last unless substr($_,-1) eq "\n";
 		$pos= tell($fh);
 		next unless $_ =~ /^progress: (([[:alpha:]][\w.]*) )?(.*)/;
 		my ($step_id, $remainder)= ($2, $3);
-		my $status= $self->step_status($step_id, 1, \my @status_parent);
+		my $state= $self->step_state($step_id, 1, \my @state_parent);
 		# First, check for progress number followed by optional message
 		if ($remainder =~ m,^([\d.]+)(/(\d+))?( (.*))?,) {
 			my ($num, $denom, $message)= ($1, $3, $5);
 			$message= '' unless defined $message;
 			$message =~ s/^- //; # "- " is optional syntax
-			$status->{message}= $message;
-			$status->{progress}= $num+0;
+			$state->{message}= $message;
+			$state->{progress}= $num+0;
 			if (defined $denom) {
-				$status->{pos}= $num;
-				$status->{max}= $denom;
-				$status->{progress} /= $denom;
+				$state->{current}= $num;
+				$state->{total}= $denom;
+				$state->{progress} /= $denom;
 			}
-			if ($status->{contribution}) {
+			if ($state->{contribution}) {
 				# Need to apply progress to parent nodes at end
-				$parent_cleanup{$status_parent[$_]}= [ $_, $status_parent[$_] ]
-					for 0..$#status_parent;
+				$parent_cleanup{$state_parent[$_]}= [ $_, $state_parent[$_] ]
+					for 0..$#state_parent;
 			}
 		}
 		elsif ($remainder =~ m,^\(([\d.]+)\) (.*),) {
 			my ($contribution, $title)= ($1, $2);
 			$title =~ s/^- //; # "- " is optional syntax
-			$status->{title}= $title;
-			$status->{contribution}= $contribution+0;
+			$state->{title}= $title;
+			$state->{contribution}= $contribution+0;
 		}
 		elsif ($remainder =~ /^\{/) {
 			my $data= JSON->new->decode($remainder);
-			$status->{data}= !defined $self->on_data? $data
+			$state->{data}= !defined $self->on_data? $data
 				: $self->on_data->($self, $step_id, $data);
 		}
 		else {
@@ -72,33 +73,31 @@ sub parse {
 	$self->input_pos($pos);
 	# apply child progress contributions to parent nodes
 	for (sort { $b->[0] <=> $a->[0] } values %parent_cleanup) {
-		my $status= $_->[1];
-		$status->{progress}= 0;
-		for (values %{$status->{step}}) {
-			$status->{progress} += $_->{progress} * $_->{contribution}
+		my $state= $_->[1];
+		$state->{progress}= 0;
+		for (values %{$state->{step}}) {
+			$state->{progress} += $_->{progress} * $_->{contribution}
 				if $_->{progress} && $_->{contribution};
 		}
 	}
-	return $self->status;
+	return $self->state;
 }
 
 
-sub step_status {
+sub step_state {
 	my ($self, $step_id, $create, $path)= @_;
-	my $status= $self->status;
-	my @status_parent;
+	my $state= $self->state;
 	if (defined $step_id and length $step_id) {
 		for (split /\./, $step_id) {
-			push @status_parent, $status;
-			$status= ($status->{step}{$_} or do {
+			push @$path, $state if $path;
+			$state= ($state->{step}{$_} or do {
 				return undef unless $create;
-				my $idx= scalar(keys %{$status->{step}});
-				$status->{step}{$_}= { idx => $idx };
+				my $idx= scalar(keys %{$state->{step}});
+				$state->{step}{$_}= { idx => $idx };
 			});
 		}
 	}
-	@$path= @status_parent if defined $path;
-	$status;
+	$state;
 }
 
 1;
@@ -115,7 +114,7 @@ Log::Progress::Parser - Parse progress data from a file
 
 =head1 VERSION
 
-version 0.00_02
+version 0.02_1
 
 =head1 SYNOPSIS
 
@@ -129,15 +128,17 @@ A practical application:
   $|= 1;
   while (1) {
     $parser->parse;
-    printf "\r%3d%%  [%-40s] ", $parser->status->{progress}*100, "#" x int($parser->status->{progress}*40);
-    last if $parser->status->{progress} >= 1;
+    printf "\r%3d%%  [%-40s] ", $parser->state->{progress}*100, "#" x int($parser->state->{progress}*40);
+    last if $parser->state->{progress} >= 1;
     sleep 1;
   }
   print "\n";
 
 =head1 DESCRIPTION
 
-This module parses progress messages from a file handle or string.
+This module parses progress messages (See
+L<the protocol description|http://github.com/nrdvana/Log-Progress/blob/master/README.md>
+for details) from a file handle or string.
 Repeated calls to the L</parse> method will continue parsing the file
 where it left off, making it relatively efficient to repeatedly call
 L</parse> on a live log file.
@@ -153,18 +154,19 @@ you want to read progress messages that are more than just ascii.
 =head2 input_pos
 
 Each call to parse makes a note of the start of the final un-finished line, so
-that the next call can pick up where it left off, assuming the file is growing.
+that the next call can pick up where it left off, assuming the file is growing
+and the file handle is seekable.
 
-=head2 status
+=head2 state
 
 This is a hashref of data describing the progress found in the input.
 
   {
     progress => $number_between_0_and_1,
     message  => $current_progress_messsage,  # empty string if no message
-    pos      => $numerator,   # only present if progress was a fraction
-    max      => $denominator, #
-    step     => \%sub_steps_by_id,
+    current  => $numerator,   # only present if progress was a fraction
+    total    => $denominator, #
+    step     => { $step_id => \%step_state, ... },
     data     => \%data,       # most recent JSON data payload, decoded
   }
 
@@ -184,7 +186,7 @@ For example, you might want to combine all the data instead of overwriting it:
   my $parser= Log::Progress::Parser->new(
     on_data => sub {
       my ($parser, $step_id, $data)= @_;
-      return Hash::Merge::merge( $parser->step_status($step_id), $data );
+      return Hash::Merge::merge( $parser->step_state($step_id), $data );
     }
   );
 
@@ -199,14 +201,17 @@ Read (any additional) L</input>, and return the L</state> field, or die trying.
 Sets L</input_pos> just beyond the end of the final complete line of text, so
 that the next call to L</parse> can follow a growing log file.
 
-=head2 step_status
+=head2 step_state
 
-  my $status= $parser->step_status($step_id, $create_if_missing);
-  my $status= $parser->step_status($step_id, $create_if_missing, \@path_out);
+  my $state= $parser->step_state($step_id, $create_if_missing);
+  my $state= $parser->step_state($step_id, $create_if_missing, \@path_out);
 
-Convenience method to traverse L</status> to get the data for a step.
+Convenience method to traverse L</state> to get the data for a step.
 If the second paramter is false, this returns undef if the step is not yet
-defined.  Else it creates a new status node, with C<idx> initialized.
+defined.  Else it creates a new state node, with C<idx> initialized.
+
+If you pass the third parameter C<@path_out> it will receive a list of the
+parent nodes of the returned state node.
 
 =head1 AUTHOR
 
